# gampc - Graphical Asynchronous Music Player Client

MPD client written in Python/Gtk+.

## Requirements

- Python 3
- PyGObject
- GLib and Gtk+ Python GObject Introspection
- Python packages:
  * ampd
  * gasyncio
  * apsw
  * xdg
  * zeroconf
